@@ -516,39 +516,6 @@ def multi_post_extract():
 
 
 def main():
-    global ROOT_PREFIX, PKGS_DIR
-
-    p = OptionParser(description="conda link tool used by installers")
-
-    p.add_option('--root-prefix',
-                 action="store",
-                 default=abspath(join(__file__, '..', '..')),
-                 help="root prefix (defaults to %default)")
-
-    p.add_option('--post',
-                 action="store",
-                 help="perform post extract (on a single package), "
-                      "in environment NAME",
-                 metavar='NAME')
-
-    opts, args = p.parse_args()
-    if args:
-        p.error('no arguments expected')
-
-    ROOT_PREFIX = opts.root_prefix.replace('//', '/')
-    PKGS_DIR = join(ROOT_PREFIX, 'pkgs')
-
-    if opts.post:
-        post_extract(opts.post)
-        return
-
-    if FORCE:
-        print("using -f (force) option")
-
-    link_idists()
-
-
-def main2():
     global SKIP_SCRIPTS, ROOT_PREFIX, PKGS_DIR
 
     p = OptionParser(description="conda post extract tool used by installers")
@@ -575,6 +542,12 @@ def main2():
                  default=abspath(join(__file__, '..', '..')),
                  help="root prefix (defaults to %default)")
 
+    p.add_option('--post',
+                 action="store",
+                 help="perform post extract (on a single package), "
+                      "in environment NAME",
+                 metavar='NAME')
+
     opts, args = p.parse_args()
     ROOT_PREFIX = opts.root_prefix.replace('//', '/')
     PKGS_DIR = join(ROOT_PREFIX, 'pkgs')
@@ -582,6 +555,13 @@ def main2():
     if args:
         p.error('no arguments expected')
 
+    if FORCE:
+        print("using -f (force) option")
+
+    if opts.post:
+        post_extract(opts.post)
+        return
+
     if opts.skip_scripts:
         SKIP_SCRIPTS = True
 
@@ -597,7 +577,10 @@ def main2():
         link_dist(opts.link_dist)
         return
 
-    post_extract()
+    if IDISTS:
+        link_idists()
+    else:
+        post_extract()
 
 
 def warn_on_special_chrs():
@@ -609,8 +592,5 @@ def warn_on_special_chrs():
 
 
 if __name__ == '__main__':
-    if IDISTS:
-        main()
-        warn_on_special_chrs()
-    else: # common usecase
-        main2()
+    main()
+    warn_on_special_chrs()
